@@ -3,6 +3,7 @@
 const Atk = imports.gi.Atk;
 const DND = imports.ui.dnd;
 const GMenu = imports.gi.GMenu;
+const GObject = imports.gi.GObject;
 const Shell = imports.gi.Shell;
 const St = imports.gi.St;
 const Clutter = imports.gi.Clutter;
@@ -400,17 +401,18 @@ class DesktopTarget {
 };
 Signals.addSignalMethods(DesktopTarget.prototype);
 
+let ApplicationsButton = GObject.registerClass(
 class ApplicationsButton extends PanelMenu.Button {
-    constructor() {
-        super(1.0, null, false);
+    _init() {
+        super._init(1.0, null, false);
 
-        this.setMenu(new ApplicationsMenu(this.actor, 1.0, St.Side.TOP, this));
+        this.setMenu(new ApplicationsMenu(this, 1.0, St.Side.TOP, this));
         Main.panel.menuManager.addMenu(this.menu);
 
         // At this moment applications menu is not keyboard navigable at
         // all (so not accessible), so it doesn't make sense to set as
         // role ATK_ROLE_MENU like other elements of the panel.
-        this.actor.accessible_role = Atk.Role.LABEL;
+        this.accessible_role = Atk.Role.LABEL;
 
         let hbox = new St.BoxLayout({ style_class: 'panel-status-menu-box' });
 
@@ -420,18 +422,17 @@ class ApplicationsButton extends PanelMenu.Button {
         hbox.add_child(this._label);
         hbox.add_child(PopupMenu.arrowIcon(St.Side.BOTTOM));
 
-        this.actor.add_actor(hbox);
-        this.actor.name = 'panelApplications';
-        this.actor.label_actor = this._label;
+        this.add_actor(hbox);
+        this.name = 'panelApplications';
+        this.label_actor = this._label;
 
-        this.actor.connect('captured-event', this._onCapturedEvent.bind(this));
-        this.actor.connect('destroy', this._onDestroy.bind(this));
+        this.connect('captured-event', this._onCapturedEvent.bind(this));
 
         this._showingId = Main.overview.connect('showing', () => {
-            this.actor.add_accessible_state (Atk.StateType.CHECKED);
+            this.add_accessible_state (Atk.StateType.CHECKED);
         });
         this._hidingId = Main.overview.connect('hiding', () => {
-            this.actor.remove_accessible_state (Atk.StateType.CHECKED);
+            this.remove_accessible_state (Atk.StateType.CHECKED);
         });
         Main.layoutManager.connect('startup-complete',
                                    this._setKeybinding.bind(this));
@@ -743,11 +744,7 @@ class ApplicationsButton extends PanelMenu.Button {
 
         return applist;
     }
-
-    destroy() {
-        super.destroy();
-    }
-};
+});
 
 let appsMenuButton;
 let activitiesButton;
