@@ -1,6 +1,7 @@
 // Drive menu extension
 const Clutter = imports.gi.Clutter;
 const Gio = imports.gi.Gio;
+const GObject = imports.gi.GObject;
 const St = imports.gi.St;
 const Shell = imports.gi.Shell;
 
@@ -113,9 +114,10 @@ class MountMenuItem extends PopupMenu.PopupBaseMenuItem {
     }
 };
 
+let DriveMenu = GObject.registerClass(
 class DriveMenu extends PanelMenu.Button {
-    constructor() {
-        super(0.0, _("Removable devices"));
+    _init() {
+        super._init(0.0, _("Removable devices"));
 
         let hbox = new St.BoxLayout({ style_class: 'panel-status-menu-box' });
         let icon = new St.Icon({ icon_name: 'media-eject-symbolic',
@@ -123,7 +125,7 @@ class DriveMenu extends PanelMenu.Button {
 
         hbox.add_child(icon);
         hbox.add_child(PopupMenu.arrowIcon(St.Side.BOTTOM));
-        this.actor.add_child(hbox);
+        this.add_child(hbox);
 
         this._monitor = Gio.VolumeMonitor.get();
         this._addedId = this._monitor.connect('mount-added', (monitor, mount) => {
@@ -151,9 +153,9 @@ class DriveMenu extends PanelMenu.Button {
 
     _updateMenuVisibility() {
         if (this._mounts.filter(i => i.actor.visible).length > 0)
-            this.actor.show();
+            this.show();
         else
-            this.actor.hide();
+            this.hide();
     }
 
     _addMount(mount) {
@@ -174,7 +176,7 @@ class DriveMenu extends PanelMenu.Button {
         log ('Removing a mount that was never added to the menu');
     }
 
-    destroy() {
+    _onDestroy() {
         if (this._addedId) {
             this._monitor.disconnect(this._addedId);
             this._monitor.disconnect(this._removedId);
@@ -182,9 +184,9 @@ class DriveMenu extends PanelMenu.Button {
             this._removedId = 0;
         }
 
-        super.destroy();
+        super._onDestroy();
     }
-};
+});
 
 function init() {
     Convenience.initTranslations();
