@@ -1,6 +1,7 @@
 const Clutter = imports.gi.Clutter;
 const GLib = imports.gi.GLib;
 const Gio = imports.gi.Gio;
+const GObject = imports.gi.GObject;
 const Gtk = imports.gi.Gtk;
 const Meta = imports.gi.Meta;
 const Shell = imports.gi.Shell;
@@ -641,16 +642,17 @@ class AppButton extends BaseButton {
 };
 
 
+let WorkspaceIndicator = GObject.registerClass(
 class WorkspaceIndicator extends PanelMenu.Button {
-    constructor() {
-        super(0.0, _("Workspace Indicator"), true);
-        this.setMenu(new PopupMenu.PopupMenu(this.actor, 0.0, St.Side.BOTTOM));
-        this.actor.add_style_class_name('window-list-workspace-indicator');
+    _init() {
+        super._init(0.0, _("Workspace Indicator"), true);
+        this.setMenu(new PopupMenu.PopupMenu(this, 0.0, St.Side.BOTTOM));
+        this.add_style_class_name('window-list-workspace-indicator');
         this.menu.actor.remove_style_class_name('panel-menu');
 
         let container = new St.Widget({ layout_manager: new Clutter.BinLayout(),
                                         x_expand: true, y_expand: true });
-        this.actor.add_actor(container);
+        this.add_actor(container);
 
         let workspaceManager = global.workspace_manager;
 
@@ -668,7 +670,7 @@ class WorkspaceIndicator extends PanelMenu.Button {
         this._workspaceManagerSignals.push(workspaceManager.connect_after('workspace-switched',
                                                                           this._updateIndicator.bind(this)));
 
-        this.actor.connect('scroll-event', this._onScrollEvent.bind(this));
+        this.connect('scroll-event', this._onScrollEvent.bind(this));
         this._updateMenu();
 
         this._settings = new Gio.Settings({ schema_id: 'org.gnome.desktop.wm.preferences' });
@@ -677,7 +679,7 @@ class WorkspaceIndicator extends PanelMenu.Button {
                                    this._updateMenu.bind(this));
     }
 
-    destroy() {
+    _onDestroy() {
         for (let i = 0; i < this._workspaceManagerSignals.length; i++)
             global.workspace_manager.disconnect(this._workspaceManagerSignals[i]);
 
@@ -686,7 +688,7 @@ class WorkspaceIndicator extends PanelMenu.Button {
             this._settingsChangedId = 0;
         }
 
-        super.destroy();
+        super._onDestroy();
     }
 
     _updateIndicator() {
@@ -759,7 +761,7 @@ class WorkspaceIndicator extends PanelMenu.Button {
         if (actor.get_n_children() > 0)
             actor.get_first_child().allocate(box, flags);
     }
-};
+});
 
 class WindowList {
     constructor(perMonitor, monitor) {
